@@ -1,3 +1,4 @@
+from os import name
 import pandas as pd
 from datetime import datetime, timedelta
 from gql import Client
@@ -7,7 +8,7 @@ from loguru import logger
 from .utils.ut_core import Utils
 from .utils.ut_autprog import AutProgUtils
 
-class Scheduler():
+class Schedule():
     def __init__(self, accessToken:str, endpoint:str) -> None:
         #endpoint = 'http://172.16.2.206:8130/graphql/'
         
@@ -15,11 +16,11 @@ class Scheduler():
             'authorization': 'Bearer ' + Automation.accessToken
         }
         
-        transport =  RequestsHTTPTransport(url=endpoint, headers=header, verify=False)
-        self.client = Client(transport=transport, fetch_schema_from_transport=True)
+        transport =  RequestsHTTPTransport(url=endpoint, headers=header, verify=True)
+        self.client = Client(transport=transport, fetch_schema_from_transport=False)
 
     def schedules(self):
-        "List schedules of all workflows"
+        "Lists schedules of all workflows"
 
         graphQLString = f'''query schedules {{
             schedules     
@@ -44,6 +45,7 @@ class Scheduler():
 
     def createSchedule(self, name:str, workflowId:str, businessKey:str, cron:str, 
         isActive:bool=True, description:str=None, variables:dict=None) -> str:
+        """Creates a schedule and returns the schedule Id"""
 
         if isActive == True:
             isActive = 'true'
@@ -62,7 +64,6 @@ class Scheduler():
             _variables += ']'
         else: _variables = ''
 
-
         graphQLString = f'''mutation createSchedule {{
             createSchedule(input:{{
                 name: "{name}"
@@ -71,14 +72,11 @@ class Scheduler():
                 cron: "{cron}"
                 description: "{description}"
                 isActive: {isActive}
-                {_variables}
-                
-                
+                {_variables}              
             }})
             {{
                 schedule {{
                     scheduleId
-                    nextFireTime
                 }}
                 errors {{
                     message
@@ -99,9 +97,87 @@ class Scheduler():
 
         return scheduleId
 
-    def deleteSchedule(self, scheduleId):
+    def updateSchedule(self, scheduleId, name:str=None, workflowId:str=None, businessKey:str=None, 
+        cron:str=None, isActive:bool=None, description:str=None, variables:dict=None) -> None:
+        """
+        Updates a schedule. Only arguments that ar not None will overwrite respective fields.
+        
+        Parameters:
+        -----------
+        scheduleId : str
+            The Id of the schedule that is to be updated.
+        name : str
+            The name of the schedule.
+        workflowId : str
+            The Id of the workflow that shall be executed with this schedule.
+        cron : str
+            The cron expression. For detailed information loop up
+            http://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html
+        isActive : bool
+            Determines, if the schedule should execute the workflow or not.
+        description : str
+            A description of the schedule.
+        variables : dict
+            A dictionary of variables that are used by tasks in the workflow.
+
+        Example:
+        --------
+        >>> vars = {
+                'var1': 99,
+                'var2': "AnyString"
+            }
+        >>> client.Scheduler.updateSchedule('112880211090997248', name='test_schedule',
+                isActive=True, variables=vars)
+        
+        """
+
+        updateScheduleArgs = ''
+
+        if name != None: updateScheduleArgs += f'name: "{name}"\n'
+        if workflowId != None: updateScheduleArgs += f'workflowId: "{workflowId}"\n'
+        if businessKey != None: updateScheduleArgs += f'businessKey: "{businessKey}"\n'
+        if cron != None: updateScheduleArgs += f'cron: "{cron}"\n'
+        if isActive != None: updateScheduleArgs += f'isActive: {str(isActive).lower()}\n'
+        if description != None: updateScheduleArgs +=  f'description: "{description}"\n'
+
+        if variables != None:
+            _variables = 'variables: [\n'
+            for k,v in variables.items():
+                _variables += f'{{key: "{k}", value: "{v}"}}\n'
+            _variables += ']'
+            updateScheduleArgs += _variables
+
+        graphQLString = f'''mutation updateSchedule {{
+            updateSchedule(
+                scheduleId: "{scheduleId}"
+                input:{{
+                    {updateScheduleArgs}
+            }})
+            {{
+                errors {{
+                    message
+                }}
+            }}
+        }}'''
+
+        result = Utils._executeGraphQL(self, graphQLString)
+        logger.debug(graphQLString)
+        if result == None: return
+
+        key = 'updateSchedule'
+        if result[key]['errors']:
+            Utils._listGraphQlErrors(result, key)
+        else:
+            logger.info(f"Schedule {scheduleId} updated.")
+
+        return
+
+    def deleteSchedule(self, scheduleId:str, force:bool=False):
         """Deletes a schedule"""
 
+        if force == False:
+            confirm = input(f"Press 'y' to delete schedule '{scheduleId}': ")
+
         graphQLString = f'''mutation deleteSchedule {{
             deleteSchedule (scheduleId: "{scheduleId}")
             {{
@@ -112,15 +188,17 @@ class Scheduler():
         }}
         '''      
 
-        result = Utils._executeGraphQL(self, graphQLString)
-        if result == None: return
+        if force == True: confirm = 'y'
+        if confirm == 'y':
+            result = Utils._executeGraphQL(self, graphQLString)
+            if result == None: return
 
-        key = 'deleteSchedule'
-        if result[key]['errors']:
-            Utils._listGraphQlErrors(result, key)
-        else:
-            logger.info(f"Schedule {scheduleId} deleted")
-            return None
+            key = 'deleteSchedule'
+            if result[key]['errors']:
+                Utils._listGraphQlErrors(result, key)
+            else:
+                logger.info(f"Schedule {scheduleId} deleted")
+                return None
 
 
     def nextFireTimes(self, workflowId:str, fromTimepoint:str=None, toTimepoint:str=None, count:int=None):
@@ -154,7 +232,9 @@ class Scheduler():
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        return result
+        df = pd.json_normalize(result['nextFireTimes'])
+
+        return df
 
 class Automation():
     accessToken = ''
@@ -188,16 +268,17 @@ class Automation():
         df = pd.json_normalize(result['workflows'])
         return df
 
-    def workflowInstances(self, workflowId:bool=None, showTasks=False) -> pd.DataFrame:
+    def workflowInstances(self, workflowId:str=None, showTasks=False) -> pd.DataFrame:
         """Shows Instances of a workflow. If workflowId=None, all Instances of all 
         workflows will be returned."""
 
         meta = ['id', 'name', 'businessKey', 'version', 'startTime', 'endTime', 'state']
+        key = 'workflowInstances'
 
         if workflowId != None:
             _workflowId = f'workflowId: "{workflowId}"'
         else:
-            _workflowId = f'all: true'
+            _workflowId = ''
 
         if showTasks != False:
             _tasks = f'''tasks {{
@@ -213,7 +294,7 @@ class Automation():
             _tasks = ''
 
         graphQLString = f'''query Instances {{
-            workflowInstances({_workflowId}) {{
+            {key}({_workflowId}, all:true) {{
                 id
                 name
                 businessKey
@@ -221,6 +302,11 @@ class Automation():
                 startTime
                 endTime
                 state
+                variables {{
+                    name
+                    value
+                    time
+                }}
                 {_tasks}
                 }}
             }}
@@ -230,10 +316,10 @@ class Automation():
         if result == None: return
 
         if showTasks != False:
-            df = pd.json_normalize(result['workflowInstances'], meta=meta, record_path=['tasks'], record_prefix='task.', errors='ignore')
+            df = pd.json_normalize(result[key], meta=meta, record_path=['tasks'], record_prefix='task.', errors='ignore')
             df = df.sort_values(by='startTime', ascending=False)
         else:
-            df = pd.json_normalize(result['workflowInstances'])
+            df = pd.json_normalize(result[key])
             df = df.sort_values(by='startTime', ascending=False)
         return df
     
