@@ -211,7 +211,7 @@ class TechStack(Utils, Meta):
         return df
 
     def items(self, inventoryName:str, references:bool=False, fields:list=None, where:str=None, 
-        pageSize:int=5000, orderBy:bool=None, asc:bool=True) -> pandas.DataFrame:
+        pageSize:int=5000, orderBy:str=None, asc:bool=True) -> pandas.DataFrame:
         """
         Returns items of an inventory in a DataFrame.
 
@@ -261,7 +261,7 @@ class TechStack(Utils, Meta):
 
         resolvedFilter = ''
         if where != None: 
-            resolvedFilter = Utils._resolveFilter(where)
+            resolvedFilter = Utils._resolveWhereString(where)
         
         if orderBy != None:
             if asc != True:
@@ -277,7 +277,7 @@ class TechStack(Utils, Meta):
         while True:
             graphQLString= f''' query getItems {{
                     {inventoryName} 
-                    (pageSize: {pageSize} {lastId} {resolvedFilter})
+                    (pageSize: {pageSize} {lastId} {resolvedFilter} {_orderBy})
                     {{
                         edges {{
                             cursor
@@ -288,7 +288,11 @@ class TechStack(Utils, Meta):
                     }}
                 }}
                 '''
-            query = gql(graphQLString)
+            try:
+                query = gql(graphQLString)
+            except Exception as err:
+                logger.error(err)
+                return
 
             if count == 0:
                 Utils._copyGraphQLString(graphQLString)
@@ -317,7 +321,6 @@ class TechStack(Utils, Meta):
         cols = [col.replace('node.','') for col in df.columns]
         df.columns = cols
         
-
         return df
 
     def inventoryProperties(self, inventoryName, namesOnly=False):
