@@ -31,9 +31,9 @@ class TimeSeries():
 
         Parameters:
         -----------
-        inventoryName : str
+        inventoryName: str
             The name of the inventory.
-        timeSeriesItems : list
+        timeSeriesItems: list
             This list contains the properties of the time series item and the properties
             of the time series feature (unit, timeUnit and factor)
 
@@ -142,20 +142,20 @@ class TimeSeries():
 
         Parameters
         ---------
-        inventoryName : str
+        inventoryName: str
             The name of the inventory to which the time series belong.
-        inventoryItemId : str
+        inventoryItemId: str
             The inventoryItemId to which data is to be written.
-        timeUnit : str
+        timeUnit: str
             Is the time unit of the time series item
-        factor : int
+        factor: int
             Is the factor of the time unit
-        unit : str
+        unit: str
             The unit of the values to be written. 
-        dataPoints : dict
+        dataPoints: dict
             Provide a dictionary with timestamps as keys.
         chunkSize:int = 10000
-            Determines the packageSize of time series values that ar written in 
+            Specifies the chunk size of time series values that are written in 
             a single transaction
         
         Example: 
@@ -242,7 +242,7 @@ class TimeSeries():
 
         Parameters
         ----------
-        data:list
+        data: list
             A list of dictionaries defining inventory, inventoryItemId, resolution, 
             unit and time series values. Is used to write time series values for
             many time series in one single transaction.
@@ -282,37 +282,30 @@ class TimeSeries():
         return
    
     def timeSeriesData(self, inventoryName:str, fromTimepoint:str, toTimepoint:str, 
-        headers:list=['_displayValue'], unit:str=None, where:str=None, 
-        timeZone:str='local', displayMode:str='compressed') -> pd.DataFrame:
+        fields:list=['_displayValue'], where:str=None, displayMode:str='compressed') -> pd.DataFrame:
         """
         Queries time series data and returns its values and properties 
         in a DataFrame.
 
         Parameter:
         --------
-        inventoryName : str
+        inventoryName: str
             The name of the inventory.
-        fromTimepoint : str
+        fromTimepoint: str
             The starting timepoint from where time series data will be retrieved. Different
             formats are available. If you use DateTimeOffset, any time zone information will be
             neglected.
-        toTimepoint : str
+        toTimepoint: str
             The ending timepoint from where time series data will be retrieved
-        headers : list | str
-            Uses the displayValue as default. If headers are not unique for each column,
-            duplicates will be omitted. If you use multiple headers, a MultiIndex DataFrame will 
+        fields:list|str = None
+            Uses the displayValue as default. If fields are not unique for each column,
+            duplicates will be omitted. If you use multiple fields, a MultiIndex DataFrame will 
             be created. Use inventoryProperties() to find out which properties are available 
             for an inventory. To access MultiIndex use syntax like <df[header1][header2]>.
-        where : str
+        where:str = None
             Use a string to add where criteria like
             'method eq "average" and location contains "Berlin"'
             Referenced items are not supported.
-        unit : str
-            Provide a convertable unit. Works only if requested time series possess 
-            the same base unit.
-        timeZone : str
-            A time zone provided in IANA or isoformat (e.g. 'Europe/Berlin' or 'CET'). Defaults
-            to the local time zone.
         displayMode : str
             compressed (default): pivot display with dropping rows and columns that are NaN
             pivot-full: full pivot with all NaN columns and rows
@@ -322,42 +315,41 @@ class TimeSeries():
         ---------
         >>> timeSeriesData('meterData', '01.10.2020', '2020-10-01T:05:30:00Z')
         >>> timeSeriesData('meterData', fromTimepoint='01.06.2020', 
-                toTimepoint='2020-06-15', headers=['meterId', 'phase'] 
+                toTimepoint='2020-06-15', fields=['meterId', 'phase'] 
                 where='measure eq "voltage"')    
         """
 
-        tz = Utils._timeZone(timeZone)
+        #tz = Utils._timeZone(timeZone)
 
         #_fromTimepoint = _convertTimestamp(fromTimepoint, tz)
         #_toTimepoint = _convertTimestamp(toTimepoint, tz)
 
-        if type(headers) != list:
-            _headers = headers
+        if type(fields) != list:
+            _fields = fields
         else:
-            _headers = ''
-            for header in headers:
-                _headers += header + '\n'
+            _fields = ''
+            for header in fields:
+                _fields += header + '\n'
 
 
         resolvedFilter = ''
         if where != None: 
             resolvedFilter = Utils._resolveFilter(where)
 
-        if unit != None:
-            _unit = f'unit:"{unit}"'
-        else:
-            _unit = ''
+        # if unit != None:
+        #     _unit = f'unit:"{unit}"'
+        # else:
+        #     _unit = ''
 
         graphQLString = f'''query timeSeriesData {{
                 {inventoryName}
                 (pageSize: 500 {resolvedFilter})
                 {{
                     nodes{{
-                        {_headers}
+                        {_fields}
                         _dataPoints (input:{{
                             from:"{fromTimepoint}"
                             to:"{toTimepoint}"
-                            {_unit}
                             }})
                         {{
                             timestamp
@@ -371,20 +363,20 @@ class TimeSeries():
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        df = pd.json_normalize(result[inventoryName]['nodes'], ['_dataPoints'], headers)
+        df = pd.json_normalize(result[inventoryName]['nodes'], ['_dataPoints'], fields)
         if df.empty:
             logger.info('The query did not produce results.')
             return df
         df.loc[(df.flag == 'MISSING'), 'value'] = nan
 
         if displayMode == 'pivot-full':
-            df = df.pivot_table(index='timestamp', columns=headers, values='value', dropna=False)
+            df = df.pivot_table(index='timestamp', columns=fields, values='value', dropna=False)
             columnNumber = len(result[inventoryName]['nodes'])
             dfColumnNumber = len(df.columns)
             if dfColumnNumber < columnNumber:
                 logger.warning(f"{columnNumber-dfColumnNumber} columns omitted due to duplicate column headers.")
         elif displayMode == 'compressed':
-            df = df.pivot_table(index='timestamp', columns=headers, values='value', dropna=True)
+            df = df.pivot_table(index='timestamp', columns=fields, values='value', dropna=True)
             columnNumber = len(result[inventoryName]['nodes'])
             dfColumnNumber = len(df.columns)
             if dfColumnNumber < columnNumber:
