@@ -126,7 +126,8 @@ class FileUtils(UtilsProperty):
                             if header[j] in isArray:
                                 item.setdefault(header[j], UtilsProperty._transformList(field, 'DateTime'))
                             else:
-                                item.setdefault(header[j], UtilsProperty._convertTimestamp(field, timeZone))
+                                #item.setdefault(header[j], FileUtils._convertTimestamp(field, timeZone, FileUtils._dateFormat(field)))
+                                item.setdefault(header[j], field)
                         else:
                             if header[j] in isArray:
                                 item.setdefault(header[j], UtilsProperty._transformList(field, 'String'))
@@ -289,6 +290,13 @@ class FileUtils(UtilsProperty):
         else:
             return str(pytz.timezone(timeZone))
 
+    def _timeZoneItems(timeZone):
+        if timeZone==None: 
+            localTimeZone = get_localzone().zone
+            return str(pytz.timezone(localTimeZone))
+        else:
+            return str(pytz.timezone('UTC'))
+
     def _convertTimestamp(timestamp, timeZone, dateTimeFormat):
 
         timestamp = datetime.strptime(timestamp, dateTimeFormat)
